@@ -9,7 +9,6 @@ class Connection:
     database: AsyncIOMotorDatabase = None
 
     async def connect(self, *args, **kwargs):
-        print(f'Connection to {args} {kwargs}')
         self.client = AsyncIOMotorClient(*args, **kwargs)
         self.database = self.client.get_default_database()
 
@@ -19,7 +18,11 @@ class Connection:
 
 
 @asynccontextmanager
-async def use_client(*args, client: Optional[AsyncIOMotorClient] = None, **kwargs):
+async def client(
+    *args,
+    client: Optional[AsyncIOMotorClient] = None,
+    **kwargs
+):
     if not client:
         client = AsyncIOMotorClient(*args, **kwargs)
     old_client = connection.client
